sqltriples.Adapters.Adapter

Package sqltriples :: Module Adapters :: Class Adapter |
[show private | hide private]
[frames | no frames]

## Class Adapter

Known Subclasses:
  `PgSQLAdapter`, `pysqlite2Adapter`

Method Summary
| `__init__(self, connection)`
| `delete_index(self, cursor, table_name)`
| `delete_sequence(self, cursor, sequence_name)`
| `delete_table(self, cursor, table_name)`
| `init_index(self, cursor, table_name)`
| `init_sequence(self, cursor, sequence_name)`
| `init_table(self, cursor, table_name)`
| `query_next_bnode_id(self, cursor, sequence_name)`

Class Variable Summary
`int` | `supports_in_tuples` = 0

Class Variable Details

    ### supports_in_tuples Type: `int` Value:
        0

Generated by Epydoc 2.1 on Sat Sep 30 00:54:37 2006 | http://epydoc.sf.net